@@ -13,7 +13,7 @@ import numpy as np
 
 
 class PlotMixin:
-    """Helper functions for plotting the arrays. """
+    """Helper functions for plotting the arrays."""
 
     def _ipython_display_(self):
         """Displays the object in IPython as a side effect"""
@@ -29,6 +29,8 @@ class PlotMixin:
 
         from rich.table import Table
         from rich.console import Console
+        from rich.panel import Panel
+
         from rich import box
 
         tables = []
@@ -37,7 +39,7 @@ class PlotMixin:
         all_attrs = self._get_attributes('non_empty_fields')
         attr_counter = Counter(all_attrs)
 
-        table = Table(box=box.SIMPLE, title='Documents Summary')
+        table = Table(box=box.SIMPLE, highlight=True)
         table.show_header = False
         table.add_row('Length', str(len(self)))
         is_homo = len(attr_counter) == 1
@@ -70,25 +72,25 @@ class PlotMixin:
                     _text = f'{_doc_text} attributes'
                 table.add_row(_text, str(_a))
 
-        tables.append(table)
+        tables.append(Panel(table, title='Documents Summary', expand=False))
 
         all_attrs_names = tuple(sorted(all_attrs_names))
         if all_attrs_names:
 
-            attr_table = Table(box=box.SIMPLE, title='Attributes Summary')
+            attr_table = Table(box=box.SIMPLE, highlight=True)
             attr_table.add_column('Attribute')
             attr_table.add_column('Data type')
             attr_table.add_column('#Unique values')
             attr_table.add_column('Has empty value')
 
-            all_attrs_values = self._get_attributes(*all_attrs_names)
-            if len(all_attrs_names) == 1:
-                all_attrs_values = [all_attrs_values]
-            for _a, _a_name in zip(all_attrs_values, all_attrs_names):
+            for _a_name in all_attrs_names:
+
                 try:
+                    _a = [getattr(d, _a_name) for d in self]
                     _a = set(_a)
                 except:
                     pass  # intentional ignore as some fields are not hashable
+
                 _set_type_a = set(type(_aa).__name__ for _aa in _a)
                 attr_table.add_row(
                     _a_name,
@@ -96,17 +98,22 @@ class PlotMixin:
                     str(len(_a)),
                     str(any(_aa is None for _aa in _a)),
                 )
-            tables.append(attr_table)
+            tables.append(Panel(attr_table, title='Attributes Summary', expand=False))
 
         storage_infos = self._get_storage_infos()
         if storage_infos:
-            storage_table = Table(box=box.SIMPLE, title='Storage Summary')
+            storage_table = Table(box=box.SIMPLE, highlight=True)
             storage_table.show_header = False
-
             for k, v in storage_infos.items():
                 storage_table.add_row(k, v)
 
-            tables.append(storage_table)
+            tables.append(
+                Panel(
+                    storage_table,
+                    title=f'[bold]{self.__class__.__name__}[/bold] Config',
+                    expand=False,
+                )
+            )
 
         console.print(*tables)
 
@@ -303,6 +310,8 @@ class PlotMixin:
         min_size: int = 16,
         channel_axis: int = -1,
         image_source: str = 'tensor',
+        skip_empty: bool = False,
+        show_progress: bool = False,
     ) -> None:
         """Generate a sprite image for all image tensors in this DocumentArray-like object.
 
@@ -314,6 +323,8 @@ class PlotMixin:
         :param min_size: the minimum size of the image
         :param channel_axis: the axis id of the color channel, ``-1`` indicates the color channel info at the last axis
         :param image_source: specify where the image comes from, can be ``uri`` or ``tensor``. empty tensor will fallback to uri
+        :param skip_empty: skip Document who has no .uri or .tensor.
+        :param show_progress: show a progresbar.
         """
         if not self:
             raise ValueError(f'{self!r} is empty')
@@ -333,8 +344,20 @@ class PlotMixin:
             [img_size * img_per_row, img_size * img_per_row, 3], dtype='uint8'
         )
         img_id = 0
+
+        from rich.progress import track
+
         try:
-            for d in self:
+            for d in track(self, description='Plotting', disable=not show_progress):
+
+                if not d.uri and d.tensor is None:
+                    if skip_empty:
+                        continue
+                    else:
+                        raise ValueError(
+                            f'Document has neither `uri` nor `tensor`, can not be plotted'
+                        )
+
                 _d = copy.deepcopy(d)
 
                 if image_source == 'uri' or (
