@@ -1,11 +1,7 @@
-import itertools
 from typing import (
-    Generator,
-    Iterator,
-    Dict,
-    Sequence,
     Optional,
     TYPE_CHECKING,
+    Iterable,
 )
 
 from ..base.backend import BaseBackendMixin
@@ -29,14 +25,12 @@ class BackendMixin(BaseBackendMixin):
     ):
         super()._init_storage(_docs, copy=copy, *args, **kwargs)
 
-        from ... import DocumentArray
-
         self._data = {}
         if _docs is None:
             return
         elif isinstance(
             _docs,
-            (DocumentArray, Sequence, Generator, Iterator, itertools.chain),
+            Iterable,
         ):
             if copy:
                 for doc in _docs:
@@ -49,8 +43,3 @@ class BackendMixin(BaseBackendMixin):
                     self.append(Document(_docs, copy=True))
                 else:
                     self.append(_docs)
-
-    def _get_storage_infos(self) -> Dict:
-        storage_infos = super()._get_storage_infos()
-        storage_infos['Backend'] = 'In Memory'
-        return storage_infos
